@@ -8,7 +8,7 @@ use Carp qw( croak );
 use Exporter ();
 
 # ABSTRACT: Portably generate config for any shell
-our $VERSION = '0.26'; # VERSION
+our $VERSION = '0.28'; # VERSION
 
 
 sub new
@@ -383,13 +383,17 @@ sub win32_space_be_gone
 
 sub cmd_escape_path
 {
-  map { _value_escape_win32($_) } @_;
+  my $path = shift() . '';
+  $path =~ s/%/%%/g;
+  $path =~ s/([&^|<>])/^$1/g;
+  $path =~ s/\n/^\n\n/g;
+  "\"$path\"";
 }
 
 
 sub powershell_escape_path
 {
-  map { _value_escape_powershell($_) } @_;
+  map { my $p = _value_escape_powershell($_); $p =~ s/ /` /g; $p } @_;
 }
 
 1;
@@ -406,7 +410,7 @@ Shell::Config::Generate - Portably generate config for any shell
 
 =head1 VERSION
 
-version 0.26
+version 0.28
 
 =head1 SYNOPSIS
 
@@ -536,7 +540,9 @@ or
 
 =head1 CONSTRUCTOR
 
-=head2 Shell::Config::Generate->new
+=head2 new
+
+ my $config = Shell::Config::Generate->new;
 
 creates an instance of She::Config::Generate.
 
@@ -566,11 +572,15 @@ This may be useful for system administrators that must support
 users that use different shells, with a single configuration
 generation script written in Perl.
 
-=head2 $config-E<gt>set( $name => $value )
+=head2 set
+
+ $config->set( $name => $value );
 
 Set an environment variable.
 
-=head2 $config-E<gt>set_path( $name => @values )
+=head2 set_path
+
+ $config->set_path( $name => @values );
 
 Sets an environment variable which is stored in standard
 'path' format (Like PATH or PERL5LIB).  In UNIX land this 
@@ -582,19 +592,25 @@ you do so you have to determine the correct separator.
 This will replace the existing path value if it already
 exists.
 
-=head2 $config-E<gt>append_path( $name => @values );
+=head2 append_path
+
+ $config->append_path( $name => @values );
 
 Appends to an environment variable which is stored in standard
 'path' format.  This will create a new environment variable if
 it doesn't already exist, or add to an existing value.
 
-=head2 $config-E<gt>prepend_path( $name => @values );
+=head2 prepend_path
+
+ $config->prepend_path( $name => @values );
 
 Prepend to an environment variable which is stored in standard
 'path' format.  This will create a new environment variable if
 it doesn't already exist, or add to an existing value.
 
-=head2 $config-E<gt>comment( $comment )
+=head2 comment
+
+ $config->comment( $comment );
 
 This will generate a comment in the appropriate format.
 
@@ -602,7 +618,10 @@ B<note> that including comments in your configuration may mean
 it will not work with the C<eval> backticks method for importing
 configurations into your shell.
 
-=head2 $config-E<gt>shebang( [ $location ] )
+=head2 shebang
+
+ $config->shebang;
+ $config->shebang($location);
 
 This will generate a shebang at the beginning of the configuration,
 making it appropriate for use as a script.  For non UNIX shells this
@@ -614,19 +633,25 @@ B<note> that the shebang in your configuration may mean
 it will not work with the C<eval> backticks method for importing
 configurations into your shell.
 
-=head2 $config-E<gt>echo_off
+=head2 echo_off
+
+ $config->echo_off;
 
 For DOS/Windows configurations (C<command.com> or C<cmd.exe>), issue this as the
 first line of the config:
 
  @echo off
 
-=head2 $config-E<gt>echo_on
+=head2 echo_on
+
+ $config->echo_on;
 
 Turn off the echo off (that is do not put anything at the beginning of
 the config) for DOS/Windows configurations (C<command.com> or C<cmd.exe>).
 
-=head2 $config-E<gt>set_alias( $alias => $command )
+=head2 set_alias
+
+ $config->set_alias( $alias => $command )
 
 Sets the given alias to the given command.
 
@@ -641,7 +666,9 @@ supports aliases.  On Windows, for PowerShell, a simple
 function is used instead of an alias so that arguments
 may be specified.
 
-=head2 $config-E<gt>set_path_sep( $sep )
+=head2 set_path_sep
+
+ $config->set_path_sep( $sep );
 
 Use C<$sep> as the path separator instead of the shell
 default path separator (generally C<:> for Unix shells 
@@ -650,14 +677,19 @@ and C<;> for Windows shells).
 Not all characters are supported, it is usually best
 to stick with the shell default or to use C<:> or C<;>.
 
-=head2 $config-E<gt>generate( [ $shell ] )
+=head2 generate
+
+ my $command_text = $config->generate;
+ my $command_text = $config->generate( $shell );
 
 Generate shell configuration code for the given shell.
 $shell is an instance of L<Shell::Guess>.  If $shell
 is not provided, then this method will use Shell::Guess
 to guess the shell that called your perl script.
 
-=head2 $config-E<gt>generate_file( $shell, $filename )
+=head2 generate_file
+
+ $config->generate_file( $shell, $filename );
 
 Generate shell configuration code for the given shell
 and write it to the given file.  $shell is an instance 
@@ -666,7 +698,9 @@ an exception.
 
 =head1 FUNCTIONS
 
-=head2 win32_space_be_gone( @path_list )
+=head2 win32_space_be_gone
+
+ my @new_path_list = win32_space_be_gone( @orig_path_list );
 
 On C<MSWin32> and C<cygwin>:
 
@@ -690,12 +724,16 @@ Elsewhere:
 
 Returns the same list passed into it
 
-=head2 cmd_escape_path( @path_list )
+=head2 cmd_escape_path
+
+ my @new_path_list = cmd_escape_path( @orig_path_list )
 
 Given a list of directory paths (or filenames), this will
 return an equivalent list of paths escaped for cmd.exe and command.com.
 
-=head2 powershell_escape_path( @path_list )
+=head2 powershell_escape_path
+
+ my @new_path_list = powershell_escape_path( @orig_path_list )
 
 Given a list of directory paths (or filenames), this will
 return an equivalent list of paths escaped for PowerShell.
@@ -764,9 +802,11 @@ Contributors:
 
 Brad Macpherson (BRAD, brad-mac)
 
+mohawk
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Graham Ollis.
+This software is copyright (c) 2017 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
